function interactivemouse(varargin)

%INTERACTIVEMOUSE   Interactive exploration of figures using a mouse.
%   INTERACTIVEMOUSE toggles the interactive mode of the current figure.
%   INTERACTIVEMOUSE ON turns on the interactive mode.
%   INTERACTIVEMOUSE OFF turns off the interactive mode.
%   INTERACTIVEMOUSE RESET sets the 'restore point' to the current view.
%   INTERACTIVEMOUSE RESTORE restores the view to the 'restore point'. The
%     'restore point' is predefined as the original view, unless the
%     current view is set as the 'restore point' with RESET.
%   INTERACTIVEMOUSE RESTORE_ORIG restores the view to the original view
%     (the view before INTERACTIVEMOUSE was initially called on this
%     figure). This 'restore point' is fixed regardless of whether RESET
%     was called or not.
%
%   INTERACTIVEMOUSE(FIG) and INTERACTIVEMOUSE(FIG, OPTION) applies to the
%     figure specified by handle FIG. FIG can be a vector of figure
%     handles. OPTION can be any of the above arguments. The figure(s) can
%     have multiple axes.
%
%   The following features are included in the interactive mode:
%     Pan          : click and drag.
%     Zoom         : right click (or CNTRL-click) and drag.
%     Center View  : double click.
%     Reset View   : <r> with the cursor over the axes region. This resets
%                    'restore point'. (see above note about RESET option)
%     Restore View : <space> with the cursor over the axes region. This
%                    restores to the 'restore point'. (see above note about
%                    RESTORE option)
%     Help window  : <h>
%     Exit mode    : <escape>
%
%   Note about Zoom Feature:
%    (2D views) : the zoom ratio depends on the location of the pointer
%                 with respect to the initial click location. Pressing the
%                 <shift> key ONCE toggles the constrained mode. In
%                 CONSTRAINED mode, the zoom ratio is constrained along
%                 x-axis, y-axis, or xy-axes depending on the pointer
%                 location. The figure window title indicates that
%                 constraint mode is active. If the axes
%                 DataAspectRatioMode is MANUAL, the zoom will always be
%                 constrained to preserve the specified aspect ratio
%                 (PROPORTIONAL mode). This is for working with images.
%                    
%    (3D views) : the zoom is always xyz-constrained (PROPORTIONAL). The
%                 aspect ratios are always preserved.
%
%   In the interactive mode, several figure and axes properties are set,
%   but the current properties are restored when the interactive mode is
%   exited. During interactive mode, the figure name changes to
%   'InteractiveMouse', and the figure is undocked (certain features
%   don't work in docked mode). This works with 2D plots, images, and 3D
%   plots (for the most part).
%   
%   Examples:
%   % Interactively examine high frequency noise
%     x=0:.001:10;
%     y=sin(x)+.01*rand(size(x));
%     plot(x,y)
%     interactivemouse;
%
%   % Multiple axes
%     load clown;
%     subplot(211);image(X);colormap(map);axis image;
%     subplot(212);plot(rand(100,1), '.-');
%     interactivemouse;
%
%   % Use LINKAXES to link multiple axes. (>R13)
%     ax(1)=subplot(211);plot(rand(100,1), 'r.-');
%     ax(2)=subplot(212);plot(rand(100,1), '.-');
%     linkaxes(ax);
%     interactivemouse;
%
%   See also ZOOM, PAN, LINKAXES

%   VERSIONS:
%     v1.0 - first version.
%     v1.1 - minor changes: indicate mode in title
%     v2.0 - constrained zooming based on the movement of the mouse. red
%            indicator line shows the type of zoom
%     v3.0 - allow unconstrained zoom. <shift> key toggles constrained
%            mode. (April 8, 2006)
%     v3.1 - fix aspect ratio bug (April 9, 2006)
%     v3.2 - fix more aspect ratio bugs (April 10, 2006)
%     v3.2.1 - optimize code. clean up documentation. fix ticklabel jitter
%              bug. (April 11, 2006)
%     v3.2.2 - fix help documentation. change the speed of animation during
%              centering and view restoring. add title bar indication for
%              view centering and view restoring. (April 11, 2006)
%     v3.3 - fix bug when calling RESET from command line. Preserve aspect
%            ratio when the DataAspectRatioMode is MANUAL. This makes sense
%            when dealing with images. Display zoom factor on the graph
%            (April 12, 2006)
%     v3.3.1 - the zoom factor displayed on the graph is in relation to the
%              original figure size, as opposed to the current figure size.
%              Make the "invisible axes" actually invisible. Modify help
%              text. (April 14, 2006)
%
%   The author would like to thank Don Riley for helpful comments in
%   improving this code.
%
%   Created in R13
%   Tested up to R2006a
%
%   Jiro Doke
%   March 30, 2006

