function [ sort_score, idx ] = MSLibMatch ( MSunknown, MSlib, varargin )
% Mass Spectral similarity index based on cross-correlation, Shimadzu's
% similarity index, Gan's substructure similarity index, Stein's and
% Scott's composite identification algorithm, dot-product, Euclidean
% distance or absolute value distance.
%
% USAGE     [ sorted_score, idx ] = MSLibMatch ( MSunknown, MSlib )
%    or     [ sorted_score, idx ] = MSLibMatch ( MSunknown, MSlib, ...
%                   'ParameterName', ParameterValue, ... )
%
% INPUT
%   MSunknown   the Mass Spectrum (MS) of the unknown compound
%   MSlib       the Mass Spectra (MS) reference library (assumed structure
%               of library as shown in 'MSLibMan' function description)
%
%   Parameters   | Values ( default values in {} )
%   -------------+---------------------------------------------------------
%   Method       | absdist | euclidean | dot | xcorr | stein_scott |
%                |          {shimadzu} | gan | gan0
%                +---------------------------------------------------------
%                | Description: (Library Search Algorithm)
%                | Method to use for computing similarity index.
%   -------------+---------------------------------------------------------
%   CheckTopIons | {1} (any positive numerical value)
%                +---------------------------------------------------------
%                | Description: (Check N Top Ions for Unknown's max ion)
%                | specifies the maximum number of top peaks to search in
%                | every mass spectrum of the reference library when
%                | looking for the unkown's maximum ion (default 1).
%   -------------+---------------------------------------------------------
%   RT           | {0} (any numerical value in same unit as in 'MSlib.RT')
%                +---------------------------------------------------------
%                | Description: (Retention Time)
%                | search within spectra of a known retention time (RT) for 
%                | narrowing search of compound in the MS reference library 
%                | 'MSlib'.
%   -------------+---------------------------------------------------------
%   RToffset     | {0} (any numerical value in same unit as in 'RT' and
%                |      'MSlib.RT')
%                +---------------------------------------------------------
%                | Description: (Retention Time offset)
%                | a +/- offset (in minutes) for narrowing search in the
%                | reference library down to spectra of known retention
%                | time (RT) - see 'RT' parameter description. This only
%                | works if the RT is reported in the MS reference library
%                | 'MSlib' and all RTs are given in minutes or in the same
%                | time unit. Default value is 0 in which case no RT will
%                | be used in facilitating the search.
%   -------------+---------------------------------------------------------
%   WeightedInt  | true | false | 1 | {0}
%                |---------------------------------------------------------
%                | Description: (Weighted Intensity)
%                | use mass weighting. This is reported as an important
%                | optimization approach for the search algorithm. The
%                | resulting weighted intensity W is computed as (see ref 2)
%                | W = [Peak Intensity]^IntPower * [Mass]^MassPower.
%   -------------+---------------------------------------------------------
%   Verbose      | true | false | {1} | 0
%                |---------------------------------------------------------
%                | Description: 
%                | display up to top 20 matches.
%
% OUTPUT
%   sorted_score    match score for every spectrum in the reference
%                   library, sorted in descending order
%   idx             array of indeces sorted according to sorted_score
%
%
% References:
% 1. Gan, F., Yang J.-H. and Liang Y.-Z. (2001). "Library Search of Mass
%    Spectra with a New Matching Algorithm Based on Substructure
%    Similarity". Anal. Sciences, May 2001, Vol. 17, pp.635-638, Jap Soc
%    Anal. Chem.
% 2. Stein, S.E. and Scott, D.R. (1994). "Optimization and Testing of Mass
%    Spectral Library Search Algorithms for Compound Identification". J Am
%    Soc Mass Spectrom 1994, 5, 895-866.
% 3. Hertz, H.S., Hites, R.A. and Biemann, K. (1971). Anal. Chem. 1971, 43,
%    681-691.
%
% See also ReadMSLib, WriteMSLib, MSLibMan
%
% Written by K. Veropoulos
% All Rights Reserved  07-11-07
%
