function [ SampleData, score ] = getTCData ( TCLib, Sample, SampleIS, pos, reldata, RI, varargin )
% GETTCDATA identifies and quantifies the target compound in position 'pos'
% of the 'TCLib' library based on the similarity score with a compound in a
% given sample at the expected retention time defined by the library.
%
% USAGE:    [ SampleData, score ] = getTCData ( TCLib, Sample, SampleIS, pos, reldata, RI )
%    or     [ SampleData, score ] = getTCData ( TCLib, Sample, SampleIS, pos, reldata, RI, ...
%                   'ParameterName', ParameterValue, ... )
%
% INPUT:    
%   TCLib        the library variable holding target compound information
%                (loaded from a file created with the 'TCLibMan' tool).
%   Sample       the sample variable holding the GC/MS raw data (usually
%                obtained from loading a '3D_data.csv' file created witht
%                the '3D_data.mac' macro of Agilent's Chemstation software.
%
%   Parameters   | Values ( default values in {} )
%   -------------+---------------------------------------------------------
%   Method       | absdist | euclidean | dot | xcorr | stein_scott |
%                |          {shimadzu} | gan | gan0
%                +---------------------------------------------------------
%                | Description: (Library Search Algorithm)
%                | Method to use for computing similarity index.
%   -------------+---------------------------------------------------------
%   WeightedInt  | true | false | 1 | {0}
%                |---------------------------------------------------------
%                | Description: (Weighted Intensity)
%                | use mass weighting. This is reported as an important
%                | optimization approach for the search algorithm. The
%                | resulting weighted intensity W is computed as (see ref 2)
%                | W = [Peak Intensity]^IntPower * [Mass]^MassPower.
%   -------------+---------------------------------------------------------
%   Verbose      | true | false | {1} | 0
%                |---------------------------------------------------------
%                | Description: 
%                | display up to top 20 matches and graphs.
%   -------------+---------------------------------------------------------
%   ScoreWeights | [w1 w2 w3 w4]    {[0.5 0.2 0.15 0.15]}
%                |---------------------------------------------------------
%                | Description: 
%                | a 1x4 vector contatining the scoring weights for mass
%                | spectral similarity (w1), retention time proximity (w2),
%                | qualifying ions agreement (w3) and excluded ions
%                | agreement (w4). The total sum of all weights should add
%                | up to 1. If not, then the default weights are used.
%   -------------+---------------------------------------------------------
%   MeasureType  | {Area} | Height
%                |---------------------------------------------------------
%                | Description: 
%                | the type of measure that will be used for quantitation
%                | (this should be the same as the type of measure that was
%                | used when building the target compound library,
%                | otherwise the calibration parameters won't be
%                | appropriate for quantitation calculations).
%   -------------+---------------------------------------------------------
%   BLfactor     | any round number
%                |---------------------------------------------------------
%                | Description: 
%                | Baseline correction sensitivity factor. The larger the
%                | number, the lower the sensitivity of the baseline trace
%                | to tha gas chromatogram's fluctuations.
%   -------------+---------------------------------------------------------
%   UserRT       | any number representing retention time in minutes
%                |---------------------------------------------------------
%                | Description: 
%                | User-specified retention time (in minutes) to be used as
%                | default retention time for locating target compound of
%                | interest.
%
% OUTPUT
%   SampleData   a two field structure ('RT' and 'MS') containing the
%                estimated target compounds' retention time and extracted
%                mass spectrum.
%   score        the computed similarity score between the target compound
%                of interest stored in the library and the identified
%                compound in the given sample. This is a combined score
%                based on similarity between mass spectra (using one of the
%                methods specified with 'Method', proximity of RT to the
%                expected RT found in the library, qualifying ion(s)
%                agreement and excluded ion(s) agreement. Each one of this
%                scores can defined to be equally significant to all other
%                measures or weighted using 'ScoreWeights'.
%
%
% References:
% 1. Gan, F., Yang J.-H. and Liang Y.-Z. (2001). "Library Search of Mass
%    Spectra with a New Matching Algorithm Based on Substructure
%    Similarity". Anal. Sciences, May 2001, Vol. 17, pp.635-638, Jap Soc
%    Anal. Chem.
% 2. Stein, S.E. and Scott, D.R. (1994). "Optimization and Testing of Mass
%    Spectral Library Search Algorithms for Compound Identification". J Am
%    Soc Mass Spectrom 1994, 5, 895-866.
% 3. Hertz, H.S., Hites, R.A. and Biemann, K. (1971). Anal. Chem. 1971, 43,
%    681-691.
%
% See also ReadMSLib, WriteMSLib, MSLibMan, MSLibMatch, MSscore, TCid_quant
%
% Written by K. Veropoulos
% All Rights Reserved  April 7, 2008
%
