function model_opt = csvm_opt (Ttr, tr, varargin)
%CSVM_OPT performs an optimized C-SVM training on the data set 'tr'
%by applying cross-validation and grid-search to find the optimum
%parameters C and gamma (of the RBF kernel).
%
% USAGE:    model_opt = csvm_opt ( Ttr, tr )
%           model_opt = csvm_opt ( Ttr, tr, 'PropertyName', PropertyValue, ... )
%
% INPUT:    tr  - input samples (can be either a MxN matrix of N samples of
%                 M variables or a cell array of MxNi matrices, where i =
%                 1..no_of_cells; in case 'tr' is a cell array, CSVM_OPT
%                 will do a k-fold cross-validation splitting the data by
%                 randomly selected groups as defined in the cell array,
%                 instead of individual samples - this is particularly
%                 useful when it is desired to group similar samples
%                 together and not allow CSVM_OPT to separate them during
%                 k-fold cross-validation; for example, in biometrics
%                 multiple samples may be obtained from each person in a
%                 database, in which case it would be desirable to keep all
%                 samples from the same person together, when the person is
%                 used as training or validation example)
%           Ttr - target values for each sample (can be either a 1xN matrix
%                 of N target values or a cell array of 1xNi vectors, each
%                 vector corresponding to a group of labels as defined by
%                 'tr' when this is also a cell array)
%
%           Properties (optional): Names -- Values
%           'C'         -- range of values for parameter C (cost) of C-SVC,
%                          epsilon-SVR, and nu-SVR in LibSVM as base 2
%                          exponents (default range: [-5:15])
%               example: model_opt = csvm_opt ( Ttr, tr, 'C', [-5:15])
%                  % will use 2^(-5), 2^(-4), ..., 2^14, 2^15 for C
%           'gamma'     -- range of values for parameter C (cost) of C-SVC,
%                          epsilon-SVR, and nu-SVR in LibSVM as base 2
%                          exponents (default range: [-15:3])
%               example: model_opt = csvm_opt ( Ttr, tr, 'gamma', [-15:3])
%                  % will use 2^(-15), 2^(-14), ..., 2^2, 2^3 for gamma
%           'quitemode' -- flag for output display. Values:
%                       'off'   display progress and results (default)
%                       'on'    use quite mode (do not display anything)
%
%   NOTE: if both C and gamma ranges are given scalars instead of vectors,
%         no optimization will be performed
%
% OUTPUT:   model_opt - optimised SVM model for the predictor to be used
%                       with function 'svm_predict'
%
% Ref: "A Practical Guide to Support Vector Classification"
%       by Chih-Wei Hsu, Chih-Chung Chang, and Chih-Jen Lin
%       (http://www.csie.ntu.edu.tw/~cjlin/papers/guide/guide.pdf)
%
%
% See also: PARSGRID, FEATSELS, CSVM_FS
%
% K. Veropoulos
% kvero@dri.edu or k_veropoulos@freemail.gr
