function progf= timebar(varargin)
% USAGE: 
% timebar(prog)                  % Update progress bar.
% timebar(text)                  % New message text.
% timebar(prog, text)            % Update progress bar and new message text.
% timebar(text, arg1, arg2, ...) % New message text, works like sprintf(...).
% timebar()                      % Deletes the timebar window.
% 
% And for compatibility with the original Matlab waitbar:
% timebar(prog, handle)
% handle= timebar(prog, handle, text)
% handle= timebar(prog, text, <property name/value list>)
% 
% A Matlab waitbar compatible replacement that is faster and more functional. 
% 
% ARGUMENTS:
% prog         (scalar, 0 <= prog <= 1) Progress value.
% text         (string) Sets/changes a message.
% handle       (numeric) Is ignored -- for compatibility with original waitbar.
% callback     (string) Is ignored -- for compatibility with original waitbar.
% <prop. ...>  (list) Sets figure properties to respective value. Special properties:
%              'DelayPeriod'   (default: 5.0)        Time until window is shown, [0, 60]. 
%              'LingerPeriod'  (default: 1.0)        Time until window is hidden, [0, 60]. 
%              'MinUpdateTime' (default: 0.5)        Minimum time between updates, [0, 10].
%              'Name'          (default: 'Progress') Progress bar window name.
%              'BarColor'      (default: 'b')        Progress bar colour. 
%              'CreateCancelBtn'                     For compatibility. Ignored. 
% 
% FUNCTIONALITY, like Matlab's original waitbar, but with some additions:
% 1.  It stays on top of other figures. 
% 2.  Minimal, really minimal, execution time overhead (some 10% of original waitbar's).
% 3.  Simpler to use, simpler calling and no figure handle to pass along.
% 4.  Only one timebar window, so no old ones left around.
% 5.  Remaining time estimated and presented.
% 6.  Delay of 5 seconds before the timebar is shown (no flashing at quick tasks).
% 7.  Window position is remembered during a Matlab session.
% 8.  Window is hidden 2 seconds after reaching prog == 1.0. If another task follows, 
%     there is time to continue progress reporting with no window flashing.
% 9.  If there is no window environment, textual feedback is used.
% 10. Information on process start and cpu time used. 
% 
% BUGS: If you find any bugs, please let me know: peder at axensten dot se.
% 
% EXAMPLE 1, simplest possible:
% nEnd= 100;
% for n= 1:nEnd
% pause(0.2); % Do stuff
% timebar(n/nEnd);
% end
% 
% EXAMPLE 2, you can be more informative:
% nEnd= 100;
% timebar(0, '(1 of 2) Preparing...', 'DelayPeriod', 0, 'LingerPeriod', 0, ...
%                 'MinUpdateTime', 0, 'Name', 'Other title...', 'BarColor', [0 1 0]);
% for n= 1:nEnd
% pause(0.1); % Prepare stuff
% timebar(n/nEnd);
% end
% timebar(0, '(2 of 2) Calculating...');
% for n= 1:nEnd
% pause(0.1); % Calculate stuff
% timebar(n/nEnd);
% end
% 
% 
% COPYRIGHT:   2005, 2006 Peder Axensten. 
%              This file may be used according to the GNU General Public License.

% KEYWORDS:    wait bar, progress bar, process, time left, ETA
% INSPIRATORS: progressbar (6922), waitwaitbar (10795), Matlab waitbar.
% REQS:	       Matlab 6.5.1 (R13SP1). Might work (but is untested) on older versions.
